@@ -80,7 +80,7 @@ class QctrlGraphQLEnvironment(GraphQLEnvironment):
 
     @lru_cache()
     def field_to_attr(self, field_name: str) -> str:
-        """ Uses inflection to convert a GraphQL
+        """Uses inflection to convert a GraphQL
         field name to an attribute name.
 
         Parameters
@@ -102,8 +102,7 @@ class QctrlGraphQLEnvironment(GraphQLEnvironment):
         result_type: GraphQLType,
         data: Any,
     ) -> DocumentNode:
-        """Returns the corresponding GraphQL mutation query.
-        """
+        """Returns the corresponding GraphQL mutation query."""
         payload = self.format_payload(input_type, data)
         selection = self.get_selection(result_type, self._action_selection_override)
 
@@ -116,8 +115,7 @@ class QctrlGraphQLEnvironment(GraphQLEnvironment):
     def wait_for_completion(
         self, field_type: GraphQLType, obj: Any, refresh_query: DocumentNode
     ):
-        """Waits until the corresponding action is completed on the server.
-        """
+        """Waits until the corresponding action is completed on the server."""
         _wait = Wait()
 
         with tqdm(total=100, leave=False) as progress_bar:
@@ -177,7 +175,11 @@ class QctrlGraphQLEnvironment(GraphQLEnvironment):
                 }}
             }}
         }}"""
-        ).format(action_id=action_id, field_type=field_type.name, selection=selection,)
+        ).format(
+            action_id=action_id,
+            field_type=field_type.name,
+            selection=selection,
+        )
 
         LOGGER.debug("query:%s", query)
         return gql(query)
