@@ -25,8 +25,7 @@ from qctrl.builders.type_registry import TypeOverrideMixin
 
 
 class ComplexArrayInputHandler(NamedInputObjectHandler, TypeOverrideMixin):
-    """Custom handler for ComplexArrayInput.
-    """
+    """Custom handler for ComplexArrayInput."""
 
     _type_hint = np.ndarray
     _input_object_name = "ComplexArrayInput"
