@@ -28,15 +28,13 @@ from qctrl.builders.graphql_utils.handlers.mixins import ScalarMixin
 
 
 def _encode_custom_scalar(value: Any) -> Any:
-    """Encodes a custom scalar value.
-    """
+    """Encodes a custom scalar value."""
     result = json.dumps(value, cls=DataTypeEncoder)
     return json.dumps(result)
 
 
 def _decode_custom_scalar(value: Any) -> Any:
-    """Decodes a custom scalar value.
-    """
+    """Decodes a custom scalar value."""
     return json.loads(value, cls=DataTypeDecoder)
 
 
@@ -55,8 +53,7 @@ def _decode_unix_scalar(value: str) -> datetime:
 
 
 class JsonStringScalarHandler(ScalarMixin, BaseHandler):
-    """Custom scalar handler for JsonString.
-    """
+    """Custom scalar handler for JsonString."""
 
     _scalar_name = "JsonString"
     _scalar_encoder = _encode_custom_scalar
@@ -66,8 +63,7 @@ class JsonStringScalarHandler(ScalarMixin, BaseHandler):
 
 
 class DateTimeScalarHandler(ScalarMixin, BaseHandler):
-    """Custom scalar handler for DateTime.
-    """
+    """Custom scalar handler for DateTime."""
 
     _scalar_name = "DateTime"
     _scalar_allowed_type = datetime
@@ -76,8 +72,7 @@ class DateTimeScalarHandler(ScalarMixin, BaseHandler):
 
 
 class GraphScalarHandler(ScalarMixin, BaseHandler):
-    """Custom scalar handler for Graph.
-    """
+    """Custom scalar handler for Graph."""
 
     _scalar_name = "Graph"
     _scalar_encoder = _encode_custom_scalar
@@ -87,8 +82,7 @@ class GraphScalarHandler(ScalarMixin, BaseHandler):
 
 
 class JsonDictScalarHandler(ScalarMixin, BaseHandler):
-    """Custom scalar handler for JsonDict.
-    """
+    """Custom scalar handler for JsonDict."""
 
     _scalar_name = "JsonDict"
     _scalar_encoder = _encode_custom_scalar
@@ -98,8 +92,7 @@ class JsonDictScalarHandler(ScalarMixin, BaseHandler):
 
 
 class UnixTimeScalarHandler(ScalarMixin, BaseHandler):
-    """Custom scalar handler for UnixTime.
-    """
+    """Custom scalar handler for UnixTime."""
 
     _scalar_name = "UnixTime"
     _scalar_allowed_type = datetime
