@@ -81,7 +81,10 @@ def build_function(
     def func(**kwargs):
         disable_result_cache = kwargs.pop("disable_result_cache", False)
         query = env.build_mutation_query(
-            mutation_name, input_type, mutation_field.type, kwargs,
+            mutation_name,
+            input_type,
+            mutation_field.type,
+            kwargs,
         )
 
         LOGGER.debug("query:%s", query)
@@ -115,7 +118,11 @@ def build_function(
     func.__name__ = _get_function_name(mutation_name)
 
     # build signature and sign function
-    signature = build_signature(env, input_type, mutation_field.type,)
+    signature = build_signature(
+        env,
+        input_type,
+        mutation_field.type,
+    )
 
     func = signature(func)
 
@@ -185,7 +192,10 @@ def build_signature(
         returns = _get_type_hint(env, return_type, base=ResultMixin)
 
         if returns is not forge.FParameter.empty:
-            signature = forge.compose(signature, forge.returns(returns),)
+            signature = forge.compose(
+                signature,
+                forge.returns(returns),
+            )
 
     return signature
 
