@@ -36,8 +36,7 @@ LOGGER = logging.getLogger(__name__)
 
 
 class ObjectHandler(BaseHandler, SelectionMixin, DataMixin):
-    """Handler for GraphQLObject types.
-    """
+    """Handler for GraphQLObject types."""
 
     _field_type = GraphQLObjectType
 
