@@ -98,8 +98,7 @@ class TypeRegistry(BaseTypeRegistry):
 
     @cached_property
     def _overrides(self):
-        """Collects all type overrides from the environment.
-        """
+        """Collects all type overrides from the environment."""
         _overrides = {}
 
         for handler in self.env.iter_handlers(TypeOverrideMixin):
@@ -113,8 +112,7 @@ class TypeRegistry(BaseTypeRegistry):
 
     @cached_property
     def _scalar_types(self):
-        """Collects all scalar handlers from the environment.
-        """
+        """Collects all scalar handlers from the environment."""
         _scalar_types = {}
 
         for handler in self.env.iter_handlers(ScalarMixin):
@@ -123,8 +121,7 @@ class TypeRegistry(BaseTypeRegistry):
         return _scalar_types
 
     def get_scalar_type_hint(self, field_type: GraphQLScalarType) -> Optional[type]:
-        """Returns the type hint for the given scalar type.
-        """
+        """Returns the type hint for the given scalar type."""
         return self._scalar_types.get(field_type.name)
 
     def get_type_hint(self, field_type: GraphQLType, **build_opts) -> type:
@@ -298,7 +295,10 @@ class TypeRegistry(BaseTypeRegistry):
             type_hint = self.get_type_hint(field.type)
 
             # build field definition
-            field_def = dict(kw_only=True, type=type_hint,)
+            field_def = dict(
+                kw_only=True,
+                type=type_hint,
+            )
 
             # if building non-input type, all sub-fields are
             # optional as it's possible to request partial data
@@ -358,7 +358,9 @@ class TypeRegistry(BaseTypeRegistry):
             cls.__doc__ = str(docstring)
 
         self._register(
-            cls, name=object_name, submodule=self._get_submodule(namespace),
+            cls,
+            name=object_name,
+            submodule=self._get_submodule(namespace),
         )
 
         return cls
@@ -384,7 +386,9 @@ class TypeRegistry(BaseTypeRegistry):
             cls.__doc__ = str(docstring)
 
         self._register(
-            cls, name=object_name, submodule=self._get_submodule(namespace),
+            cls,
+            name=object_name,
+            submodule=self._get_submodule(namespace),
         )
 
         return cls
