@@ -16,15 +16,11 @@
 For example:
     $ qctrl auth
 """
-import json
 import logging
 import os
 import time
 from pathlib import Path
-from typing import (
-    Any,
-    Dict,
-)
+from typing import Any
 
 import click
 import inflection
@@ -46,8 +42,11 @@ from qctrl.queries import (
     GetWorkerInfo,
     RefreshTokenQuery,
 )
+from qctrl.queries.action_export import ActionExportQuery
 from qctrl.queries.get_environment import GetQueueInfo
 from qctrl.scripts_utils import (
+    _process_output,
+    _write_action_result_to_csv,
     file_path_for_url,
     interactive_authentication,
     write_auth_file,
@@ -324,22 +323,48 @@ def access_token(api_root, output):
     _process_output({"access_token": access}, output)
 
 
-def _process_output(result: Dict, output: str = None) -> None:
+@main.command(help="Export the action data into csv file.")
+@click.option(
+    "--api-root",
+    help="Custom Q-CTRL API base URL.",
+    default=DEFAULT_API_ROOT,
+    show_default=f"{DEFAULT_API_ROOT}",
+)
+@click.option("--start-date", help="The date begin i.e 2020-12-31", required=True)
+@click.option("--end-date", help="The date till i.e 2021-06-30", required=True)
+@click.option(
+    "--ignore-test-users",
+    help="Flag to ignore the action records created by test users.",
+    default=True,
+    show_default=True,
+)
+@click.option(
+    "--file-name",
+    help="Saved file name",
+    default="result.csv",
+    show_default="result.csv",
+)
+@click.option("--path", help="Path of saved file", required=True)
+def action_export(api_root, start_date, end_date, ignore_test_users, file_name, path):
     """
-    Presents the gql response. The result would be printed or save to
-    output file with indentation.
-
-    Parameters
-    ----------
-    result: Dict
-        gql response.
-    output: str
-        output file (Default value = None).
+    Exports action data to csv file.
     """
-    if output:
-        with open(output, "w", encoding="utf-8") as file:
-            json.dump(result, file, indent=4, sort_keys=True)
-            click.echo(f"The result has written to the output file: {output}")
+    directory_path = Path.home() / path
+    if not directory_path.exists():
+        click.echo(f"Cannot find Path {directory_path}")
     else:
-        # print with indentation
-        click.echo(json.dumps(result, indent=4, sort_keys=True))
+        gql_api = create_gql_client(api_root, create_client_auth(api_root))
+        gql_env = create_environment(gql_api)
+        action_export_query = ActionExportQuery(
+            gql_api, gql_env, start_date, end_date, ignore_test_users
+        )
+        action_result = action_export_query()
+
+        if not action_result:
+            click.echo("No match action data found")
+        else:
+            # format and save the result to file
+            saved_path = directory_path / file_name
+            _write_action_result_to_csv(saved_path, action_result)
+
+            click.echo(f"The result has been saved to {saved_path}")
